##  Notifications
When the quality seal of a fact sheet is broken, all responsible and accountable subscribers of the fact sheet receive a notification. These notifications are accessible through all channels configured in your notification settings.
You can change your notification settings by navigating to Notifications under My settings and selecting Data Quality. To learn more about notifications, see [Notifications](https://help.sap.com/docs/leanix/ea/notifications?locale=en-US&state=PRODUCTION&version=CLOUD "Adjust your notification preferences to stay informed about significant changes in your workspace, monitor tasks that need your attention, and stay updated on other relevant activities.").
![Setting Notification for Breaking of Quality Seal](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274e9d107a441014b5f58880c4022ac9_LowRes.png)
Setting Notification for Breaking of Quality Seal
YesNo
Send
